@@ -1,12 +1,12 @@
-#' Compute the regularized divergence of topics
+#' Optimize the number of topics
 #'
-#' Compute the regularized topic divergence to find the optimal
+#' `divergence()` computes the regularized topic divergence to find the optimal
 #' number of topics for LDA.
-#' @param x a LDA model fitted by [textmodel_seededlda()] or [textmodel_lda()].
-#' @param regularize if `TRUE`, compute the regularized divergence.
 #' @param min_size the minimum size of topics for regularized topic divergence.
 #'   Ignored when `regularize = FALSE`.
 #' @param select names of topics for which the divergence is computed.
+#' @param x a LDA model fitted by [textmodel_seededlda()] or [textmodel_lda()].
+#' @param regularize if `TRUE`, returns the regularized divergence.
 #' @details `divergence()` computes the average Jensen-Shannon divergence
 #'   between all the pairs of topic vectors in `x$phi`. The divergence score
 #'   maximizes when the chosen number of topic `k` is optimal (Deveaud et al.,
@@ -21,22 +21,24 @@
 #'   A Semi-supervised Algorithm for Topic-specific Analysis of Sentences".
 #'   *Social Science Computer Review*.
 #' @export
-divergence <- function(x, regularize = TRUE, min_size = 0.01, select = NULL) {
+divergence <- function(x, min_size = 0.01, select = NULL,
+                       regularize = TRUE) {
     UseMethod("divergence")
 }
 
 #' @importFrom proxyC dist
 #' @export
-divergence.textmodel_lda <- function(x, regularize = TRUE, min_size = 0.01,
-                                     select = NULL) {
+divergence.textmodel_lda <- function(x, min_size = 0.01, select = NULL,
+                                     regularize = TRUE) {
 
-    regularize <- check_logical(regularize)
     min_size <- check_double(min_size, min = 0, max = 1)
+    select <- check_character(select, min_len = 2, max_len = nrow(x$phi),
+                              strict = TRUE, allow_null = TRUE)
+    regularize <- check_logical(regularize, strict = TRUE)
 
     if (is.null(select)) {
         l <- rep(TRUE, nrow(x$phi))
     } else {
-        select <- check_character(select, min_len = 2, max_len = nrow(x$phi), strict = TRUE)
         if (any(!select %in% rownames(x$phi)))
             stop("Selected topics must be in the model", call. = FALSE)
         l <- rownames(x$phi) %in% select
